==> sign-center-api-0.0.2.2-20180428.084506-6-sources.jar: cn/com/duiba/sign/center/api/dto/SignPetStatusDto.java <==
package cn.com.duiba.sign.center.api.dto;

import cn.com.duiba.sign.center.api.enums.signpet.SignPetRewardEnum;
import cn.com.duiba.sign.center.api.enums.signpet.SignPetStatusEnum;
import cn.com.duiba.sign.center.api.enums.signpet.SignPetStatusTypeEnum;

import java.io.Serializable;
import java.util.Date;

/**
 * @author liugq
 * @date created in 2018/4/23
 * @description:
 */
public class SignPetStatusDto implements Serializable{

    private static final long serialVersionUID = -1100784839585659725L;

    /**
     * id
     **/
    private Long id;
    /**
     * 活动ID
     **/
    private Long activityId;
    /**
     * 活动名称
     **/
    private String statusName;
    /**
     * 1:主动状态 2.被动状态
     **/
    private SignPetStatusTypeEnum statusType;
    /**
     * 状态值，1:正常 2:外出 3:吃饭 4:学习 5:喝水 6:睡觉
     **/
    private  SignPetStatusEnum petStatus;
    /**
     * 持续时间,分钟
     **/
    private Integer duration;
    /**
     * 出现概率
     **/
    private Integer rate;
    /**
     * 是否可被打断(0-否，1-是)
     **/
    private Boolean canStop;
    /**
     * 1:无奖励、2:粮食、3.活动插件、4.集卡
     **/
    private SignPetRewardEnum awardType;
    /**
     * 活动插件id，或者集卡活动id
     **/
    private Long awardPluginId;
    /**
     * 每日奖励次数限制
     **/
    private Integer awardLimit;
    /**
     * 每次奖励次数
     */
    private Integer awardCount;
    /**
     * 状态可进入的起始时间
     **/
    private Date startLimit;
    /**
     * 状态可进入的最晚时间
     **/
    private Date endLimit;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getActivityId() {
        return activityId;
    }

    public void setActivityId(Long activityId) {
        this.activityId = activityId;
    }

    public String getStatusName() {
        return statusName;
    }

    public void setStatusName(String statusName) {
        this.statusName = statusName;
    }

    public SignPetStatusTypeEnum getStatusType() {
        return statusType;
    }

    public void setStatusType(SignPetStatusTypeEnum statusType) {
        this.statusType = statusType;
    }

    public SignPetStatusEnum getPetStatus() {
        return petStatus;
    }

    public void setPetStatus(SignPetStatusEnum petStatus) {
        this.petStatus = petStatus;
    }

    public Integer getDuration() {
        return duration;
    }

    public void setDuration(Integer duration) {
        this.duration = duration;
    }

    public Integer getRate() {
        return rate;
    }

    public void setRate(Integer rate) {
        this.rate = rate;
    }

    public Boolean getCanStop() {
        return canStop;
    }

    public void setCanStop(Boolean canStop) {
        this.canStop = canStop;
    }

    public SignPetRewardEnum getAwardType() {
        return awardType;
    }

    public void setAwardType(SignPetRewardEnum awardType) {
        this.awardType = awardType;
    }

    public Long getAwardPluginId() {
        return awardPluginId;
    }

    public void setAwardPluginId(Long awardPluginId) {
        this.awardPluginId = awardPluginId;
    }

    public Integer getAwardLimit() {
        return awardLimit;
    }

    public void setAwardLimit(Integer awardLimit) {
        this.awardLimit = awardLimit;
    }

    public Integer getAwardCount() {
        return awardCount;
    }

    public void setAwardCount(Integer awardCount) {
        this.awardCount = awardCount;
    }

    public Date getStartLimit() {
        return startLimit;
    }

    public void setStartLimit(Date startLimit) {
        this.startLimit = startLimit;
    }

    public Date getEndLimit() {
        return endLimit;
    }

    public void setEndLimit(Date endLimit) {
        this.endLimit = endLimit;
    }
}

==> sign-center-api-0.0.3.3-20180505.051425-2-sources.jar: cn/com/duiba/sign/center/api/dto/SignPetStatusDto.java <==
package cn.com.duiba.sign.center.api.dto;

import cn.com.duiba.sign.center.api.enums.signpet.SignPetRewardEnum;
import cn.com.duiba.sign.center.api.enums.signpet.SignPetStatusEnum;
import cn.com.duiba.sign.center.api.enums.signpet.SignPetStatusTypeEnum;

import java.io.Serializable;
import java.util.Date;

/**
 * @author liugq
 * @date created in 2018/4/23
 * @description:
 */
public class SignPetStatusDto implements Serializable{

    private static final long serialVersionUID = -1100784839585659725L;

    /**
     * id
     **/
    private Long id;
    /**
     * 活动ID
     **/
    private Long activityId;
    /**
     * 活动名称
     **/
    private String statusName;
    /**
     * 1:主动状态 2.被动状态
     **/
    private SignPetStatusTypeEnum statusType;
    /**
     * 状态值，1:正常 2:外出 3:吃饭 4:学习 5:喝水 6:睡觉
     **/
    private  SignPetStatusEnum petStatus;
    /**
     * 持续时间,分钟
     **/
    private Integer duration;
    /**
     * 出现概率
     **/
    private Integer rate;
    /**
     * 是否可被打断(0-否，1-是)
     **/
    private Boolean canStop;
    /**
     * 1:无奖励、2:粮食、3.活动插件、4.集卡
     **/
    private SignPetRewardEnum awardType;
    /**
     * 活动插件id，或者集卡活动id
     **/
    private Long awardPluginId;
    /**
     * 每日奖励次数限制
     **/
    private Integer awardLimit;
    /**
     * 每次奖励次数
     */
    private Integer awardCount;
    /**
     * 状态可进入的起始时间,hh:mm
     **/
    private String startLimit;
    /**
     * 状态可进入的最晚时间,hh:mm
     **/
    private String endLimit;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getActivityId() {
        return activityId;
    }

    public void setActivityId(Long activityId) {
        this.activityId = activityId;
    }

    public String getStatusName() {
        return statusName;
    }

    public void setStatusName(String statusName) {
        this.statusName = statusName;
    }

    public SignPetStatusTypeEnum getStatusType() {
        return statusType;
    }

    public void setStatusType(SignPetStatusTypeEnum statusType) {
        this.statusType = statusType;
    }

    public SignPetStatusEnum getPetStatus() {
        return petStatus;
    }

    public void setPetStatus(SignPetStatusEnum petStatus) {
        this.petStatus = petStatus;
    }

    public Integer getDuration() {
        return duration;
    }

    public void setDuration(Integer duration) {
        this.duration = duration;
    }

    public Integer getRate() {
        return rate;
    }

    public void setRate(Integer rate) {
        this.rate = rate;
    }

    public Boolean getCanStop() {
        return canStop;
    }

    public void setCanStop(Boolean canStop) {
        this.canStop = canStop;
    }

    public SignPetRewardEnum getAwardType() {
        return awardType;
    }

    public void setAwardType(SignPetRewardEnum awardType) {
        this.awardType = awardType;
    }

    public Long getAwardPluginId() {
        return awardPluginId;
    }

    public void setAwardPluginId(Long awardPluginId) {
        this.awardPluginId = awardPluginId;
    }

    public Integer getAwardLimit() {
        return awardLimit;
    }

    public void setAwardLimit(Integer awardLimit) {
        this.awardLimit = awardLimit;
    }

    public Integer getAwardCount() {
        return awardCount;
    }

    public void setAwardCount(Integer awardCount) {
        this.awardCount = awardCount;
    }

    public String getStartLimit() {
        return startLimit;
    }

    public void setStartLimit(String startLimit) {
        this.startLimit = startLimit;
    }

    public String getEndLimit() {
        return endLimit;
    }

    public void setEndLimit(String endLimit) {
        this.endLimit = endLimit;
    }
}
